#
# spec file for package itinerary
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0
%define kpim6_version 6.4.2

%bcond_without released
Name:           itinerary
Version:        25.04.2
Release:        1.1
Summary:        Itinerary and boarding pass management application
License:        LGPL-2.0-or-later
URL:            https://apps.kde.org/itinerary
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel >= %{qt6_version}
BuildRequires:  shared-mime-info
BuildRequires:  cmake(KF6CalendarCore) >= %{kf6_version}
BuildRequires:  cmake(KF6Contacts) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6FileMetaData) >= %{kf6_version}
BuildRequires:  cmake(KF6Holidays) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6NetworkManagerQt) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6UnitConversion) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KHealthCertificate)
BuildRequires:  cmake(KOSMIndoorMap)
BuildRequires:  cmake(KPim6Itinerary) >= %{kpim6_version}
BuildRequires:  cmake(KPim6PkPass) >= %{kpim6_version}
BuildRequires:  cmake(KPublicTransport)
BuildRequires:  cmake(LibIcal)
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Positioning) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(QuotientQt6)
BuildRequires:  pkgconfig(zlib)
# itinerary uses icons from the breeze theme
Requires:       kf6-breeze-icons
# Upstream insists in having these as build dependencies...
BuildRequires:  kf6-kirigami-imports >= %{kf6_version}
BuildRequires:  kf6-ki18n-imports >= %{kf6_version}
BuildRequires:  kf6-prison-imports >= %{kf6_version}
BuildRequires:  qt6qmlimport(QtLocation)
BuildRequires:  qt6qmlimport(QtPositioning)
BuildRequires:  qt6qmlimport(org.kde.kopeninghours)
BuildRequires:  qt6qmlimport(org.kde.kosmindoormap)
# QML imports
Requires:       kf6-kcalendarcore-imports >= %{kf6_version}
Requires:       kf6-kcontacts-imports >= %{kf6_version}
Requires:       kf6-ki18n-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-knotifications-imports >= %{kf6_version}
Requires:       kf6-prison-imports >= %{kf6_version}
Requires:       khealthcertificate-imports
Requires:       kirigami-addons6
Requires:       kopeninghours-imports
Requires:       kosmindoormap-imports
Requires:       kpublictransport-imports
Requires:       qt6-declarative-imports
Requires:       qt6-location
Requires:       qt6-multimedia-imports
Requires:       qt6-positioning-imports

%description
Itinerary and boarding pass management application.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 \
  -DBUILD_TESTING:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%check
# Test aborts
excluded_tests+="itinerary-self-test"
%ifarch %{ix86}
# Rounding issue on x86
excluded_tests+="|timelinemodeltest|transfertest|localizertest|"
%endif

%ctest --exclude-regex "($excluded_tests)"

%files
%license LICENSES/*
%{_kf6_applicationsdir}/org.kde.itinerary.desktop
%{_kf6_appstreamdir}/org.kde.itinerary.appdata.xml
%{_kf6_bindir}/itinerary
%{_kf6_debugdir}/org_kde_itinerary.categories
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.itinerary.svg
%{_kf6_libdir}/libSolidExtras.so
%{_kf6_notificationsdir}/itinerary.notifyrc
%dir %{_kf6_plugindir}/kf6/kfilemetadata
%{_kf6_plugindir}/kf6/kfilemetadata/kfilemetadata_itineraryextractor.so
%dir %{_kf6_plugindir}/kf6/thumbcreator
%{_kf6_plugindir}/kf6/thumbcreator/itinerarythumbnail.so
%{_kf6_qmldir}/org/kde/solidextras/

%files lang -f %{name}.lang

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- Changes since 25.04.1:
  * Add 25.04.2 release notes
  * Fix showing train direction on the vehicle layout page
  * Ensure there's enough space for the scan mode floating buttons
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- Changes since 25.04.0:
  * Add 25.04.1 release notes
  * Don't search for rental vehicle journeys
  * Also poll for updates for newly imported reservations in the far future
  * Fix geocoding when no country is selected
  * Fill in missing address bits when geocoding
  * Postprocess reservations after editing
  * Apply live data journey updates to entire batches in one go
  * Fix display of arrival stop notes
  * Improve trip group action state handling for ending trips
  * Disable Appium tests on the CI for now
  * Build APKs against released dependencies
  * cmake: We're linking to CorePrivate so search for it
  * Fix typo in Qt translation catalog exclusion pattern
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- Changes since 25.03.90:
  * Fix typo in Qt translation catalog exclusion pattern
  * Add 25.04.0 release notes
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Too many changes since 24.12.3, only listing bugfixes:
  * Override instead of merge destination names when applying new journeys (kde#474096)
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * Fix trip group map bounding box computations for individual locations
  * Don't hide essential trip group map elements on low zoom levels
  * Don't try to update a reservation to a different type
  * Disable DB online import for now
  * Update APK version logic to the latest ECM
  * Reapply "Determine APK version code from CI_PIPELINE_CREATED_AT when set"
  * Unify usage of the document-import icon
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Add 24.12.2 release notes
  * Round temperatures before checking whether we need to show a range
  * Allow transfers to favorite location independent of the next reservation
  * Retain stop geo coordinates when merging realtime data
  * Fix QML syntax for partial alternative journey searches
  * Fix importing passes or other things without an attached trip group
  * Fix deleting generic pkpass passes
  * Add Appstream source code and donation links
  * Add Appstream form factor information
  * Fix map bounding box computation for path-less journeys
  * Build 24.12.1 release APK against latest KPublicTransport branch
  * Remove unused string from Android manifest
  * Bundle icons needed by the latest Kirigami Addons about dialog
  * Add 24.12.1 release notes
* Wed Jan 29 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add additional install dependencies
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Ignore cancelled elements when determining weather forecast length
  * TripGroupPage: Add separator in first FormCard
  * Override instead of merge destination names when applying new journeys (kde#474096)
  * Fix adding DST info elements in single trip group mode
  * Fix crash on importing health certificates
  * Use FormCardButton in SheetDrawer
  * Optimize CountryComboBox
  * Allow to add transfers in more cases
  * Unify checks for *.itinerary files
  * Don't show the welcome page again when there's already a trip group
  * Reduce Appium reservation test even more aggressively in 24.12
  * Make Appium reservationtest reliably pass again
  * Exclude FluentWinUI3 QtQuick Controls style from the APK as well
  * Exclude unused Qt translation catalogs
  * Build release packages against released dependencies
  * Improve look of RadioSelector
  * Remove useless spacing
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * Add 24.12.0 release notes
  * Add branding color
  * Update to libQuotient 0.9.1
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Fix export icon
  * Build packages against stable dependencies
  * Don't classify end-less trip groups starting today as past trips
  * Fix dangling reference warnings
  * Add new Matrix connections to AccountRegistry
  * Fix unequal spacing
  * Update to 6.8 Flatpak runtime
  * Trigger login when pressing Return in the Matrix password field
  * Set a better Matrix device name
  * Ensure empty formcard is not visible
  * Fix restaurant names not shown on the trip group map
  * Trip group editor focus the text field when opened
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * Download all parts of DB tickets (kde#494696)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Add 24.08.3 release notes
  * Enable app-specific language selection in Android 33
  * Skip Appium tests on Qt 6.8.0 on the CI that need pending Qt fixes
  * Fix Android build with Qt 6.8
  * Fix checks for journey disruption effects
  * Add 24.08.2 release notes
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Update translation catalog exclusion list
  * Handle one more OSM hotel tagging variant
  * Make the URL detection heuristics a bit more clever
  * Workaround for intents doing nothing
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Adjust to Craft Boost blueprint changes
  * Add 24.08.1 release notes
  * Add diagnostic information about language settings
  * Fix icon recoloring for the transfer icon
  * Only search for KF::ColorScheme on Android
  * Enable automatic dark mode handling on Android
  * Add 24.08.0 release notes
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Fix storing the arrival time when editing a ferry reservation (kde#487885)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Add 24.05.2 release notes
  * Don't register KContacts QML types with KF >= 6.3
  * Fix reading/writing of all-day events to/from the Android system calendar
  * Fix corrupted release notes
  * Use the same branch for PIM dependencies
  * Port away from deprecated KMime API
  * Build APKs against release branch dependencies
  * Also request calendar read permissions when requesting write permissions
  * Hide barcode area in pkpasses entirely if there is none
  * Add 24.05.1 release notes
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Fix disabling development mode
  * Fix storing the arrival time when editing a ferry reservation (kde#487885)
  * Fix notifyrc qrc path
  * Less eagerly continue trip group searching after finding a loop
  * Make sure we only show arrival delays if we show the arrival time
  * Work around Kirigami Addons now having a QtWidgets dependency
  * Add Google Play publishing job template
  * Use 6.7 Flatpak runtime
  * Work around Emoji fonts configuration being broken in Flatpak
  * Fix FreeBSD asserts due to QCoreApplication being used during teardown
  * Fix invalid XML in SVG icons
  * Add 24.05.0 release notes
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Port away from deprecated Quotient::Accounts global variable
  * Adapt to source-incompatible changes in Qt's 6.7 JNI API
  * Use release versions of Poppler and Quotient in stable branch Flatpaks
  * Port away from Quotient's connectSingleShot()
  * Build against stable branches
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes to list here.
- Drop patch, merged upstream:
  * 0001-Work-around-event-queue-ordering-changes-in-Qt-6.7.patch
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Add 24.02.2 release notes
  * Fix journey section layout being messed up by Qt 6.7
  * Remove unused kde/plasma-mobile version override
  * Fix centering pkpass barcode alt texts
  * Fix handling of departure disruptions
  * Remove outdated information about APKs
  * Prevent overly large pkpass footer images from messing up the layout
  * Fix icons coloring for coach type icons
  * Use release versions of all dependencies in Craft builds
  * Use released Frameworks in Craft builds
- Add upstream change:
  * 0001-Work-around-event-queue-ordering-changes-in-Qt-6.7.patch
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Add 24.02.1 release notes
  * Adapt build options for KF6
  * Add enough space at the end for the floating button
  * Use the actual 6.6 Flatpak SDK now
  * Filter implausible geo coder results
* Tue Mar 12 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Move the %%find_lang call into %%install section
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Tighten QML module dependency requirements
  * Add developer_name tag to Appstream data
  * Update release note for 24.02
  * Adapt Craft ignore list to renamed KMime translation catalog
  * Add Craft ignore list from Craft's blueprint
  * Add CD job for publishing on Google Play
  * Disable the journey map on the live status page
  * Fix check for displaying departure notes on train trips
  * Improve display of notes sheet
  * MapView: Improve mouse zooming behaviour
  * Fix closing the journey replacement warning dialog
  * Build our own dependencies in Flatpak from release branches
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Use ECM master version for Craft
  * Add job for submitting Qt 5 APKs to Google Play
  * Set bug address in KAboutData for the about dialog bug reporting action
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Add 23.08.3 release notes
  * Exclude Poppler's fallback fonts from the Itinerary APK
  * Use include:project for all templates
  * Use Kirigami Addons from the kf5 branch
  * Use merged Craft Android template
  * snapcraft: add file to reuse.
  * snapcraft: initial import snapcraft files.
  * Update Android asset exclusion list
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Add more sanity checks for transfers
  * More reasonable clang-tidy settings
  * Fix several word wrap issues for health certificate details
  * Ensure DB ticket reference is upper-cased
  * Disable Poppler Qt bindings
  * Fix Flatpak build after PIM switched master to Qt6
  * Use stable branch for Qt5 PIM libraries
  * Require POST_NOTIFICATION permission for Android SDK 33
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Add 23.08.1 release notes
  * Add release APK CI jobs
  * Fix editing bus and train elements without an associated ticket object (kde#474234)
  * Manually manage permissions in the Android manifest
  * Correctly size constrain Apple Wallet generic pass thumbnail image
  * Fix typos in the release notes
  * Fix progress computation on the initial journey stopover
  * Unbreak Flatpak build after the runtime removed ZXing
  * Add 23.08.0 release notes
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add 23.08.0 release notes
  * Correctly clip weather forecasts at the end of the available data
  * Include icons needed by Kirigami Addons
  * Fix sunset/sunrise computation for weather icons
  * Remove health certificate Android shortcut
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Generalize the live data polling cooldown to all queries
  * Test pkpass update failure behind a captive portal
  * Don't poll pkpass updates in a continuous loop on errors
  * Don't check in PkPassManager whether a pass should be updated
  * Unify checks for updatable pkpasses
  * Check for live updatable pkpass files once they are actually added
  * Centralize QNetworkAccessManager creation
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes to list here.
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Add 23.04.3 release notes
  * Ensure we pass content: URLs fully encoded to Android API and QFile (kde#470643)
  * Add icon for boat/ferry reservations in the calendar
  * Explicitly specify supported types when importing from a calendar
  * Add map argument unit test for static elements at the begin/end
  * Fix infinite loop in computing static location map arguments
  * Fail less dramatically when ending up with an unknown pass
  * Work around the Android back key closing the app on secondary layers
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Add 23.04.2 release notes
  * Fix horizontal padding in editor page
  * Adapt test data to the changed name prefix cleaning in kitinerary
  * Don't attempt to select favorite locations based on invalid coordinates
  * Set better transfer delta times for restaurant reservations
  * Be more strict in discarding elements we cannot get live updates for
  * Properly check if the element a transfer is attached is a location change
  * Always pass passId to ActionsCard
  * Work around KUnitConversion deadlocking when needing a currency update (kde#469562)
  * Cache holiday region lookups
  * Fix attaching documents on multi-traveler reservations (kde#469347)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Consider transfers when determining the full trip group extend
  * Add 23.04.1 release notes
  * Validate imported passes and tickets
  * Fix imported PDFs losing their file name on Android
  * Improve Apple Wallet boarding pass layout for overflowing primary labels
  * Don't show the current element progress on canceled elements
  * Don't poll cancelled reservations for live updates
  * Ignore canceled reservations for transfers
  * Don't trigger connection warnings for canceled reservations
  * Make links in event descriptions clickable
* Mon Apr 24 2023 Christophe Marin <christophe@krop.fr>
- Add a breeze5-icons requirements. Itinerary requires this
  icon theme.
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Sun Jan 29 2023 Luca Beltrame <lbeltrame@kde.org>
- Add runtime requirement of ki18n-imports
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes to list here.
- Use GCC 10 for building kate on Leap 15.
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Format user visible numbers using the current locale
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Add 21.12.2 release notes
  * Add 21.12.1 release notes
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Don't break the timeline page when leaving development mode
  * Also make unit tests work against older KF versions without KI18nLocaleData
  * Fix station map platforms being mis-detected without live data
  * Get at least one live data update even for far future elements
  * Add 21.12.0 release notes
  * Fix ASAN unit test failure on the CI
  * Sanity-check model indexes
  * Fix certificate ordering when facing invalid dates
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Remove CI from stable branch again
  * Add CI for real
  * Enable new GitLab CI on stable branch.
  * Fix trend icon sizes on the statistics page
  * Also round the journey query delegate header background
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Also hide the issuer field when not present
  * Don't color health certificates without a verified signature green
  * NL CoronaCheck certificates specify no birth year, show that correctly
  * Handle fields not provided by the NL CoronaCheck certificates
  * Hide the health certificate swipe view when there are no certificates
  * Fix opening attached documents
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Add PDF417 barcode support for tickets (kde#444324)
  * Fix driving side warning for left-side driving countries (kde#440728)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Include iso-codes data files needed by KF::I18n 5.88
  * [EventDelegate] Hide location name if there is none
  * [Delegates] Use preferredWidth instead of width
  * Prevent map panning in the location picker switching to the previous page
  * For departureCountry check departureLocation
  * Don't let checkbox labels force the minimum page width (kde#443200)
  * Add 21.08.2 changelog
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Too many changes since 21.08.1, only listing bugfixes:
  * Also word-wrap welcome page headers (kde#443200)
  * Fix timeline model test breaking during the last hour of the day (kde#442821)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Properly encode mail attachments received via FairEmail share intents
  * Rename icon according to Flatpak convention
  * Add breeze as fallback icon theme
  * Add 21.08.0 changelog
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Tue Aug  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add more runtime requirements.
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Too many changes to list here.
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes to list here.
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Hotfix for upcoming CardListView changes in Kirigami 5.84
  * Add content rating to appstream data
  * Fix line breaks in departure view disruption notes
  * Force using org.kde.desktop style on non-Android
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Fix application version display in tarball builds
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Exclude kde5_xml_mimetypes.qm from the APK
  * Wrap overly long event venue names
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Exclude a few more translation catalogs we don't need
  * Give the country combo box enough space
  * Complete the exclusion list for all iso-codes catalogs we don't need
  * Set the APK version based on what is defined in CMake
  * Extend the asset ignore pattern
  * Don't install files we don't need on Android
  * Refine the packaging exclusion list
  * Add APK exclusion lists for libraries and assets
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
- Drop upstream patch:
  * Update-weather-API-endpoint.patch
* Fri Mar  5 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patch:
  * Update-weather-API-endpoint.patch
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Properly handle journey section begins/ends when setting platform names
  * Make tests independent of locale configuration
  * Align transfer and journey query pages
  * Port timeline delegates away from QtQuick layouts
  * Explicitly anchor address label to the left
  * Fix opening the indoor map for elements that aren't location changes
* Thu Dec 10 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Add a category to the desktop file (kde#429114)
  * Fix build with older CMake versions
- Drop upstream patch:
  * 0001-Fix-build-with-older-CMake-versions.patch
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- itinerary is now released using the KDE release service.
- Add upstream patch:
  * 0001-Fix-build-with-older-CMake-versions.patch
* Tue Jul 23 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
